@@ -1,7 +1,9 @@
 from .ColorScales import ColorScales
+from .Select import Select
 from .WebvizPluginPlaceholder import WebvizPluginPlaceholder
 
 __all__ = [
     "ColorScales",
+    "Select",
     "WebvizPluginPlaceholder"
 ]
\ No newline at end of file
